aboutsummaryrefslogtreecommitdiffstats
path: root/GPL/traffic_scripts/PacketVerifier.py
diff options
context:
space:
mode:
Diffstat (limited to 'GPL/traffic_scripts/PacketVerifier.py')
-rw-r--r--GPL/traffic_scripts/PacketVerifier.py5
1 files changed, 3 insertions, 2 deletions
diff --git a/GPL/traffic_scripts/PacketVerifier.py b/GPL/traffic_scripts/PacketVerifier.py
index c915921625..bb91b9361c 100644
--- a/GPL/traffic_scripts/PacketVerifier.py
+++ b/GPL/traffic_scripts/PacketVerifier.py
@@ -331,9 +331,10 @@ def create_gratuitous_arp_request(src_mac, src_ip):
def auto_pad(packet):
"""Pads zeroes at the end of the packet if the total packet length is less
then 64 bytes in case of IPv4 or 78 bytes in case of IPv6.
"""
- min_len = 78 if packet.haslayer(IPv6) else 64
+ # TODO: add document explaining deduction of FCS part
+ min_len = 78 if packet.haslayer(IPv6) else 60
pad_layer = Raw if packet.haslayer(Raw) \
else Padding if packet.haslayer(Padding) else None
if pad_layer:
@@ -331,9 +331,10 @@ def create_gratuitous_arp_request(src_mac, src_ip):
def auto_pad(packet):
"""Pads zeroes at the end of the packet if the total packet length is less
- then 64 bytes in case of IPv4 or 78 bytes in case of IPv6.
+ then 60 bytes in case of IPv4 or 78 bytes in case of IPv6.
"""